==> scala-relay-compiler-0.8.1.tgz: package/realex/multipleroots/out/SpecificUserView_viewer.scala <==
/**
 * scala-relay-compiler: 
 * GENERATED, DON'T MANUALLY EDIT.
 */
package relay.generated
/*

objName:      fragment
docType:      ConcreteFragment
*/

import _root_.scala.scalajs.js
import _root_.scala.scalajs.js.|

trait SpecificUserView_viewer extends js.Object {
  /** No spreads, just combining. */
  val user : SpecificUserView_viewer.User
  val id : String
}


object SpecificUserView_viewer extends _root_.relay.graphql.GenericGraphQLTaggedNode {

  ////////////////////////////////////
  ////// Supporting classes begin here
  ////////////////////////////////////
  trait UserUser extends js.Object {
    val lastName : String
    val firstName : String
  }
  trait User extends js.Object {
    /** No spreads, just combining. */
    val user : UserUser
    val id : String
  }

  ///////////////////////////
  ////// Implicits begin here
  ///////////////////////////

  implicit def SpecificUserView_viewer2AdminCore_viewer(f: SpecificUserView_viewer): AdminCore_viewer = f.asInstanceOf[AdminCore_viewer]

  val query: _root_.relay.graphql.ConcreteFragment = _root_.scala.scalajs.js.JSON.parse("""{
  "argumentDefinitions": [],
  "kind": "Fragment",
  "metadata": null,
  "name": "SpecificUserView_viewer",
  "selections": [
    {
      "kind": "ScalarField",
      "alias": null,
      "args": null,
      "name": "id",
      "storageKey": null
    },
    {
      "kind": "LinkedField",
      "alias": null,
      "args": null,
      "concreteType": "FullUser",
      "name": "user",
      "plural": false,
      "selections": [
        {
          "kind": "ScalarField",
          "alias": null,
          "args": null,
          "name": "id",
          "storageKey": null
        },
        {
          "kind": "LinkedField",
          "alias": null,
          "args": null,
          "concreteType": "User",
          "name": "user",
          "plural": false,
          "selections": [
            {
              "kind": "ScalarField",
              "alias": null,
              "args": null,
              "name": "firstName",
              "storageKey": null
            },
            {
              "kind": "ScalarField",
              "alias": null,
              "args": null,
              "name": "lastName",
              "storageKey": null
            }
          ],
          "storageKey": null
        }
      ],
      "storageKey": null
    },
    {
      "kind": "FragmentSpread",
      "name": "AdminCore_viewer",
      "args": null
    }
  ],
  "type": "Viewer"
}""").asInstanceOf[_root_.relay.graphql.ConcreteFragment]
  val devText: String = """"""
}

==> scala-relay-compiler-0.12.0.tgz: package/realex/multipleroots/out/SpecificUserView_viewer.scala <==
/**
 * scala-relay-compiler: 
 * GENERATED, DON'T MANUALLY EDIT.
 * objName:      fragment
 * docType:      ConcreteFragment
 */
package relay.generated

import _root_.scala.scalajs.js
import _root_.scala.scalajs.js.|

trait SpecificUserView_viewer extends js.Object {
  /** No spreads, just combining. */
  val user : SpecificUserView_viewer.User
  val id : String
}


object SpecificUserView_viewer extends _root_.relay.graphql.GenericGraphQLTaggedNode {

  ////////////////////////////////////
  ////// Supporting classes begin here
  ////////////////////////////////////
  trait UserUser extends js.Object {
    val lastName : String
    val firstName : String
  }
  trait User extends js.Object {
    /** No spreads, just combining. */
    val user : UserUser
    val id : String
  }

  ///////////////////////////
  ////// Implicits begin here
  ///////////////////////////

  implicit def SpecificUserView_viewer2AdminCore_viewer(f: SpecificUserView_viewer): AdminCore_viewer = f.asInstanceOf[AdminCore_viewer]

  val query: _root_.relay.graphql.ConcreteFragment = _root_.scala.scalajs.js.eval("""((function(){
var v0 = {
  "kind": "ScalarField",
  "alias": null,
  "name": "id",
  "args": null,
  "storageKey": null
};
return {
  "kind": "Fragment",
  "name": "SpecificUserView_viewer",
  "type": "Viewer",
  "metadata": null,
  "argumentDefinitions": [],
  "selections": [
    v0,
    {
      "kind": "LinkedField",
      "alias": null,
      "name": "user",
      "storageKey": null,
      "args": null,
      "concreteType": "FullUser",
      "plural": false,
      "selections": [
        v0,
        {
          "kind": "LinkedField",
          "alias": null,
          "name": "user",
          "storageKey": null,
          "args": null,
          "concreteType": "User",
          "plural": false,
          "selections": [
            {
              "kind": "ScalarField",
              "alias": null,
              "name": "firstName",
              "args": null,
              "storageKey": null
            },
            {
              "kind": "ScalarField",
              "alias": null,
              "name": "lastName",
              "args": null,
              "storageKey": null
            }
          ]
        }
      ]
    },
    {
      "kind": "FragmentSpread",
      "name": "AdminCore_viewer",
      "args": null
    }
  ]
};
})())""").asInstanceOf[_root_.relay.graphql.ConcreteFragment]
  val devText: String = """"""
}
